@@ -13,11 +13,6 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
-#ifdef MAEMO
-#	include <hildon/hildon.h>
-#	include <hildon/hildon-fm.h>
-#endif
-
 #ifdef HAVE_UNITY
 	#include <unity/unity/unity.h>
 #endif
@@ -34,9 +29,7 @@ gboolean had_error, paused, first_load_groups = TRUE, dryrunning = FALSE, must_s
 gchar **groups = NULL, **argv, *error_list = NULL, *watch_oldfile = NULL;
 GtkWidget *rsync_window = NULL;
 gboolean config_output = FALSE, config_remember = TRUE, config_errorlist = FALSE, config_log = FALSE, config_log_overwrite = FALSE, config_fastscroll = TRUE;
-#ifndef MAEMO
 gboolean config_switchbutton = FALSE, config_trayicon = FALSE;
-#endif
 gint64 startime, pausedtime;
 gchar config_command[MAXPATH], *grsync_dir, *rsync_help = NULL, *rsync_man = NULL;
 FILE *log_file = NULL;
@@ -47,6 +40,20 @@ GtkTreeModelFilter *filter = NULL;
 gboolean more = FALSE, first = TRUE;
 
 
+void dialog_set_labels_selectable(GtkWidget *dialog) {
+	void _set_label_selectable(gpointer data, gpointer user_data) {
+		GtkWidget *widget = GTK_WIDGET(data);
+		if (GTK_IS_LABEL(widget)) gtk_label_set_selectable(GTK_LABEL(widget), TRUE);
+	}
+
+	GtkWidget *area = gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG(dialog));
+	GtkContainer *box = (GtkContainer *) area;
+	GList *children = gtk_container_get_children(box);
+	g_list_foreach(children, _set_label_selectable, NULL);
+	g_list_free(children);
+}
+
+
 void on_trayicon_activate(GObject *trayIcon, gpointer window) {
 	// gtk_widget_show(GTK_WIDGET(window));
 	gtk_window_deiconify(GTK_WINDOW(window));
@@ -58,7 +65,7 @@ void set_trayicon(gboolean flag) {
 	if (flag) {
 		if (trayIcon == NULL) {
 			trayIcon = gtk_status_icon_new_from_file(icon);
-			g_signal_connect(GTK_STATUS_ICON(trayIcon), "activate", GTK_SIGNAL_FUNC(on_trayicon_activate), main_window);
+			g_signal_connect(GTK_STATUS_ICON(trayIcon), "activate", G_CALLBACK(on_trayicon_activate), main_window);
 		}
 	} else {
 		if (trayIcon != NULL) {
@@ -75,20 +82,12 @@ void set_trayicon_icon(gboolean busy) {
 }
 
 gboolean get_checkbox(gchar* name) {
-#ifndef MAEMO
 	return gtk_toggle_button_get_active((GtkToggleButton*) gtk_builder_get_object(builder, name));
-#else
-	return hildon_check_button_get_active((HildonCheckButton*) gtk_builder_get_object(builder, name));
-#endif
 }
 
 
 void set_checkbox(gchar* name, gboolean val) {
-#ifndef MAEMO
 	gtk_toggle_button_set_active((GtkToggleButton*) gtk_builder_get_object(builder, name), val);
-#else
-	hildon_check_button_set_active((HildonCheckButton*) gtk_builder_get_object(builder, name), val);
-#endif
 }
 
 
@@ -111,7 +110,7 @@ void ini_set_entry(GKeyFile* settings_file, gchar* session, gchar* name, gchar*
 void set_main_title(gchar* session, gchar* extra) {
 	gchar *stmp = g_strconcat("Grsync: ", session, " ", extra, NULL);
 	gtk_window_set_title((GtkWindow*) main_window, stmp);
-	if (trayIcon != NULL) gtk_status_icon_set_tooltip(trayIcon, stmp);
+	if (trayIcon != NULL) gtk_status_icon_set_tooltip_text(trayIcon, stmp);
 	g_free(stmp);
 }
 
@@ -165,15 +164,13 @@ void load_settings(gchar* session, gchar *filename) {
 		ini_get_boolean(settings_file, "logging", &config_log);
 		ini_get_boolean(settings_file, "logging_overwrite", &config_log_overwrite);
 		ini_get_boolean(settings_file, "fastscroll", &config_fastscroll);
-#ifndef MAEMO
 		ini_get_boolean(settings_file, "switchbutton", &config_switchbutton);
 //		gtk_widget_set_visible((GtkWidget*) gtk_builder_get_object(builder, "button_switch"), config_switchbutton);  ONLY WORKS IN GTK 2.18
 		config_switchbutton ? gtk_widget_show((GtkWidget*) gtk_builder_get_object(builder, "button_switch")) :
-			gtk_widget_hide((GtkWidget*) gtk_builder_get_object(builder, "button_switch"));
+		gtk_widget_hide((GtkWidget*) gtk_builder_get_object(builder, "button_switch"));
 
 		ini_get_boolean(settings_file, "trayicon", &config_trayicon);
 		set_trayicon(config_trayicon);
-#endif
 
 		// load window position and size
 		if (!resized) {
@@ -252,9 +249,7 @@ void load_settings(gchar* session, gchar *filename) {
 		set_checkbox("check_com_after", g_key_file_get_boolean(settings_file, session, "check_com_after", NULL));
 		set_checkbox("check_com_onerror", g_key_file_get_boolean(settings_file, session, "check_com_onerror", NULL));
 		set_checkbox("check_browse_files", g_key_file_get_boolean(settings_file, session, "check_browse_files", NULL));
-	#ifndef MAEMO
 		set_checkbox("check_superuser", g_key_file_get_boolean(settings_file, session, "check_superuser", NULL));
-	#endif
 	}
 
 	g_key_file_free (settings_file);
@@ -292,10 +287,8 @@ void save_settings(gchar *session, gchar *filename) {
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "logging", config_log);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "logging_overwrite", config_log_overwrite);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "fastscroll", config_fastscroll);
-#ifndef MAEMO
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "switchbutton", config_switchbutton);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "trayicon", config_trayicon);
-#endif
 		if (session_last != -1 && config_remember) g_key_file_set_string(settings_file, CONFIG_GROUP, "last_session", groups[session_last]);
 
 		// window position and size
@@ -376,9 +369,7 @@ void save_settings(gchar *session, gchar *filename) {
 		g_key_file_set_boolean(settings_file, session, "check_com_after", get_checkbox("check_com_after"));
 		g_key_file_set_boolean(settings_file, session, "check_com_onerror", get_checkbox("check_com_onerror"));
 		g_key_file_set_boolean(settings_file, session, "check_browse_files", get_checkbox("check_browse_files"));
-		#ifndef MAEMO
 		g_key_file_set_boolean(settings_file, session, "check_superuser", get_checkbox("check_superuser"));
-		#endif
 	}
 
 	key_data = g_key_file_to_data(settings_file, NULL, &error_handler);
@@ -480,12 +471,7 @@ void show_browse_source(GtkButton *button, gpointer user_data) {
 	gchar *curr_path = (gchar*) gtk_entry_get_text((GtkEntry*) gtk_builder_get_object(builder, "text_source"));
 	gchar *curr_folder = g_path_get_dirname(curr_path);
 
-#ifndef MAEMO
 	dialog = gtk_file_chooser_dialog_new(_("Browse"), (GtkWindow*) main_window, action, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
-#else
-	dialog = hildon_file_chooser_dialog_new((GtkWindow*) main_window, action);
-	gtk_window_set_title(GTK_WINDOW (dialog), _("Browse"));
-#endif
 	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), curr_folder);
 	if (browse_files) gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(dialog), curr_path);
 
@@ -510,12 +496,7 @@ void show_browse_dest(GtkButton *button, gpointer user_data) {
 	gchar *curr_path = (gchar*) gtk_entry_get_text((GtkEntry*) gtk_builder_get_object(builder, "text_dest"));
 	gchar *curr_folder = g_path_get_dirname(curr_path);
 
-#ifndef MAEMO
 	dialog = gtk_file_chooser_dialog_new(_("Browse"), (GtkWindow*) main_window, action, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
-#else
-	dialog = hildon_file_chooser_dialog_new ((GtkWindow*) main_window, action);
-	gtk_window_set_title(GTK_WINDOW(dialog), _("Browse"));
-#endif
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog), curr_folder);
 	if (browse_files) gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(dialog), curr_path);
 
@@ -581,9 +562,7 @@ void build_rsync_cmd() {
 
 	argv = g_new(gchar *, MAXOPT);
 	argv_tmp = g_new(gchar *, MAXOPT);
-	#ifndef MAEMO
 	if (get_checkbox("check_superuser")) argv[i++] = "pkexec";
-	#endif
 	argv[i++] = config_command;
 
 	argv[i++] = get_checkbox("check_norecur") ? "-d" : "-r";
@@ -752,16 +731,10 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 
 	grsync_dir = g_strconcat(g_get_home_dir(), "/.grsync", NULL);
 	if (!load_groups(argv_session)) {
-#ifndef MAEMO
 		error = gtk_message_dialog_new(window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL,
 			_("The session you specified on the command line doesn't exists"));
 		gtk_dialog_run(GTK_DIALOG(error));
 		gtk_widget_destroy(error);
-#else
-		error = hildon_banner_show_information(GTK_WIDGET (window),NULL,
-				_("The session you specified on the command line doesn't exists"));
-		hildon_banner_set_timeout(HILDON_BANNER (error),4000);
-#endif
 		g_free(argv_session);
 		argv_session = g_strconcat("default", NULL);
 		cmdline_execute = FALSE;
@@ -771,13 +744,8 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 
 	stmp = g_strconcat(config_command, " --help", NULL);
 	if (!g_spawn_command_line_sync(stmp, &rsync_help, NULL, NULL, NULL)) {
-#ifndef MAEMO
 		error = gtk_message_dialog_new(window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL,
 			_("Unable to execute the rsync command line tool. It is needed by this program. You may need to install the rsync package or make it available in the default executable search PATH. See file/preferences to change the default rsync executable command."));
-#else
-		error = hildon_note_new_information(GTK_WINDOW (window),
-				_("Unable to execute the rsync command line tool. It is needed by this program. You may need to install the rsync package or make it available in the default executable search PATH. See file/preferences to change the default rsync executable command."));
-#endif
 		gtk_dialog_run(GTK_DIALOG(error));
 		gtk_widget_destroy(error);
 	} else {
@@ -815,7 +783,7 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 }
 
 
-void on_main_destroy(GtkObject *object, gpointer user_data) {
+void on_main_destroy(GtkWidget *object, gpointer user_data) {
 	gint sel = gtk_combo_box_get_active((GtkComboBox*) gtk_builder_get_object(builder, "combo_session"));
 	save_settings(groups[sel], NULL);
 	g_strfreev(groups);
@@ -860,7 +828,7 @@ void on_close_clicked(GtkButton *button, gpointer user_data) {
 			gtk_widget_hide(rsync_window);
 		}
 	}
-	if (cmdline_execute && !more && !cmdline_stayopen) on_main_destroy((GtkObject*) main_window, NULL);
+	if (cmdline_execute && !more && !cmdline_stayopen) on_main_destroy((GtkWidget*) main_window, NULL);
 }
 
 
@@ -1088,6 +1056,21 @@ gboolean scroll_idle(gpointer data) {
 }
 
 
+gchar* escape_cmd(gchar **inv) {
+	gchar *tmp, **outv;
+	gint i = 0;
+	outv = g_new(gchar *, MAXOPT);
+	while (inv[i] != NULL) {
+		outv[i] = ((g_strstr_len(inv[i], -1, " ") || inv[i][0] == 0)? g_shell_quote(inv[i]) : g_strdup(inv[i]));
+		i++;
+	}
+	outv[i] = NULL;
+	tmp = g_strjoinv(" ", outv);
+	g_free(outv);
+	return tmp;
+}
+
+
 void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 	gint out, err;
 	GtkTextBuffer *buffer;
@@ -1117,7 +1100,7 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 		comm_before = g_strconcat("", NULL);
 	}
 
-	comm_str = g_strjoinv(" ", argv);
+	comm_str = escape_cmd(argv);
 	if (halt) tmpc = "";
 	else {
 		if (dryrunning) tmpc =_("** Launching RSYNC command (simulation mode):\n");
@@ -1164,20 +1147,15 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 		gtk_widget_set_sensitive((GtkWidget*) gtk_builder_get_object(builder, "button_pause"), FALSE);
 		gtk_widget_set_sensitive((GtkWidget*) view, TRUE);
 		if (!halt) {
-#ifndef MAEMO
 			error = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL, _("Cannot execute rsync"));
 			gtk_dialog_run(GTK_DIALOG(error));
 			gtk_widget_destroy(error);
-#else
-			error = hildon_banner_show_information(GTK_WIDGET(main_window), NULL, _("Cannot execute rsync"));
-			hildon_banner_set_timeout(HILDON_BANNER(error), 4000);
-#endif
 		}
 	}
 }
 
 
-void on_rsync_hide(GtkObject *object, gpointer user_data) {
+void on_rsync_hide(GtkWidget *object, gpointer user_data) {
 	if (rsync_pid) {
 		if (paused) superkill(SIGCONT);
 		superkill(SIGTERM);
@@ -1213,32 +1191,20 @@ void on_session_add_clicked(GtkButton *button, gpointer user_data) {
 		is_set = get_checkbox("checkbutton_isset");
 
 		if (strcmp(CONFIG_GROUP, newses) == 0 || strcmp("", newses) == 0 || strchr(newses, '/') != NULL) {
-#ifndef MAEMO
 			confirm = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CANCEL, _("This session name is reserved, you cannot call it like this"));
 			gtk_dialog_run(GTK_DIALOG(confirm));
 			gtk_widget_destroy(confirm);
-#else
-			confirm = hildon_banner_show_information(GTK_WIDGET (main_window),NULL,
-					_("This session name is reserved, you cannot call it like this"));
-			hildon_banner_set_timeout(HILDON_BANNER (confirm),4000);
-#endif
 			gtk_widget_hide(add);
 			return;
 		}
 
 		while (groups[i] != NULL && strcmp(groups[i], newses)) i++;
 		if (groups[i] != NULL) {
-#ifndef MAEMO
 			confirm = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CANCEL, _("A session named like this already exists"));
 			gtk_dialog_run(GTK_DIALOG(confirm));
 			gtk_widget_destroy(confirm);
-#else
-			confirm = hildon_banner_show_information(GTK_WIDGET (main_window),NULL,
-					_("A session named like this already exists"));
-			hildon_banner_set_timeout(HILDON_BANNER (confirm),4000);
-#endif
 			gtk_widget_hide(add);
 			return;
 		}
@@ -1263,27 +1229,15 @@ void on_session_del_clicked(GtkButton *button, gpointer user_data) {
 
 	i = gtk_combo_box_get_active((GtkComboBox*) gtk_builder_get_object(builder, "combo_session"));
 	if (strcmp(groups[i], "default") == 0) {
-#ifndef MAEMO
 		confirm = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
 			GTK_BUTTONS_CANCEL, _("You cannot delete the default session"));
 		gtk_dialog_run(GTK_DIALOG(confirm));
 		gtk_widget_destroy(confirm);
-#else
-		confirm = hildon_banner_show_information(GTK_WIDGET (main_window),NULL,
-				_("You cannot delete the default session"));
-		hildon_banner_set_timeout(HILDON_BANNER (confirm),4000);
-#endif
 		return;
 	}
 
-#ifndef MAEMO
 	confirm = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION,
 		GTK_BUTTONS_OK_CANCEL, _("Are you sure you want to delete the '%s' session?"), groups[i]);
-#else
-	gchar conftxt[255];
-	g_sprintf(conftxt,_("Are you sure you want to delete the '%s' session?"),groups[i]);
-	confirm = hildon_note_new_confirmation (GTK_WINDOW (main_window),conftxt);
-#endif
 	result = gtk_dialog_run(GTK_DIALOG(confirm));
 	gtk_widget_destroy(confirm);
 
@@ -1319,7 +1273,6 @@ void on_button_about_clicked(GtkButton *button, gpointer user_data) {
 
 	gchar *authors[] = {
 		_("Written by Piero Orsoni <orsoni@gmail.com>"),
-		_("Maemo compatibility by Luca Donaggio <donaggio@gmail.com>"),
 		_("Additional bug-fixing by Luca Marturana <lucamarturana@gmail.com>"),
 
 		_("Dutch translation by Frank de Bruijn <f.d.de.bruijn@gmail.com>"),
@@ -1389,10 +1342,8 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	set_checkbox("check_log", config_log);
 	set_checkbox("check_log_overwrite", config_log_overwrite);
 	set_checkbox("check_fastscroll", config_fastscroll);
-#ifndef MAEMO
 	set_checkbox("check_switchbutton", config_switchbutton);
 	set_checkbox("check_trayicon", config_trayicon);
-#endif
 
 	result = gtk_dialog_run((GtkDialog*) config);
 	if (result == GTK_RESPONSE_OK) {
@@ -1403,7 +1354,6 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 		config_log = get_checkbox("check_log");
 		config_log_overwrite = get_checkbox("check_log_overwrite");
 		config_fastscroll = get_checkbox("check_fastscroll");
-#ifndef MAEMO
 		config_switchbutton = get_checkbox("check_switchbutton");
 //		gtk_widget_set_visible((GtkWidget*) gtk_builder_get_object(builder, "button_switch"), config_switchbutton);  ONLY WORKS IN GTK 2.18
 		config_switchbutton ? gtk_widget_show((GtkWidget*) gtk_builder_get_object(builder, "button_switch")) :
@@ -1411,7 +1361,6 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 		config_trayicon = get_checkbox("check_trayicon");
 		set_trayicon(config_trayicon);
-#endif
 	}
 	gtk_widget_hide(config);
 }
@@ -1419,26 +1368,11 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 void on_rsync_info_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	GtkWidget *dialog;
-#ifdef MAEMO
-	GtkWidget *panarea, *label;
-#endif
 	gchar *tmps, *result;
 
 	tmps = g_strconcat(config_command, " --version", NULL);
 	g_spawn_command_line_sync(tmps, &result, NULL, NULL, NULL);
-#ifndef MAEMO
 	dialog = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", result);
-#else
-	dialog = gtk_dialog_new();
-	gtk_window_set_default_size(GTK_WINDOW (dialog),-1,300);
-	panarea = hildon_pannable_area_new();
-	g_object_set(G_OBJECT (panarea),"mov-mode",HILDON_MOVEMENT_MODE_BOTH,NULL);
-	gtk_widget_show(panarea);
-	gtk_container_add(GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG (dialog))),panarea);
-	label = gtk_label_new(result);
-	gtk_widget_show(label);
-	hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (panarea),label);
-#endif
 	gtk_dialog_run(GTK_DIALOG(dialog));
 
 	gtk_widget_destroy(dialog);
@@ -1449,26 +1383,12 @@ void on_rsync_info_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 void on_commandline_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	GtkWidget *dialog;
-#ifdef MAEMO
-	GtkWidget *panarea, *label;
-#endif
 	gchar *tmps;
 
 	build_rsync_cmd();
-	tmps = g_strjoinv(" ", argv);
-#ifndef MAEMO
+	tmps = escape_cmd(argv);
 	dialog = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", tmps);
-#else
-	dialog = gtk_dialog_new();
-	gtk_window_set_default_size(GTK_WINDOW (dialog),-1,300);
-	panarea = hildon_pannable_area_new();
-	g_object_set(G_OBJECT (panarea),"mov-mode",HILDON_MOVEMENT_MODE_BOTH,NULL);
-	gtk_widget_show(panarea);
-	gtk_container_add(GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG (dialog))),panarea);
-	label = gtk_label_new(tmps);
-	gtk_widget_show(label);
-	hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (panarea),label);
-#endif
+	dialog_set_labels_selectable(dialog);
 	gtk_dialog_run(GTK_DIALOG(dialog));
 
 	gtk_widget_destroy(dialog);
@@ -1481,13 +1401,8 @@ void on_import1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	GtkWidget *dialog, *dialog2;
 	gint retval;
 
-#ifndef MAEMO
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
-#else
-	dialog = hildon_file_chooser_dialog_new ((GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_OPEN);
-	gtk_window_set_title(GTK_WINDOW (dialog), _("Browse"));
-#endif
 	if (user_data != NULL) gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(dialog), user_data);
 
 	retval = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -1496,14 +1411,9 @@ void on_import1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
 		load_settings(NULL, filename);
 
-#ifndef MAEMO
 		dialog2 = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("Session imported"));
 		gtk_dialog_run(GTK_DIALOG(dialog2));
 		gtk_widget_destroy(dialog2);
-#else
-		dialog2 = hildon_banner_show_information(GTK_WIDGET (main_window),NULL,_("Session imported"));
-		hildon_banner_set_timeout(HILDON_BANNER (dialog2),2000);
-#endif
 		g_free(filename);
 	}
 	gtk_widget_destroy(dialog);
@@ -1516,13 +1426,8 @@ void on_export1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	gint retval, i;
 
 	i = gtk_combo_box_get_active((GtkComboBox*) gtk_builder_get_object(builder, "combo_session"));
-#ifndef MAEMO
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_SAVE,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
-#else
-	dialog = hildon_file_chooser_dialog_new ((GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_SAVE);
-	gtk_window_set_title(GTK_WINDOW (dialog), _("Browse"));
-#endif
 	filename = g_strconcat(groups[i], ".grsync", NULL);
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), filename);
 	g_free(filename);
@@ -1532,14 +1437,9 @@ void on_export1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 		save_settings(groups[i], filename);
 
-#ifndef MAEMO
 		dialog2 = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("Session exported"));
 		gtk_dialog_run(GTK_DIALOG(dialog2));
 		gtk_widget_destroy(dialog2);
-#else
-		dialog2 = hildon_banner_show_information(GTK_WIDGET (main_window),NULL,_("Session exported"));
-		hildon_banner_set_timeout(HILDON_BANNER (dialog2),2000);
-#endif
 		g_free(filename);
 	}
 	gtk_widget_destroy(dialog);
@@ -1583,11 +1483,7 @@ gboolean on_main_window_window_state_event(GtkWidget *widget, GdkEventWindowStat
 
 
 void on_contribute_activate(GtkMenuItem *menuitem, gpointer user_data) {
-#ifdef MAEMO
-	g_spawn_command_line_async("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'http://www.opbyte.it/contribute.html'", NULL);
-#else
 	g_spawn_command_line_async("xdg-open http://www.opbyte.it/contribute.html", NULL);
-#endif
 }
 
 
